import { z } from "zod";
export declare enum RateType {
    VARIABLE = 0,
    FIXED = 1
}
export declare enum Amortization {
    ANNUITET = 0,
    SERIE = 1,
    REVOLVING = 2
}
export declare enum AccountType {
    LOAN = "LOAN",
    LEASING = "LEASING",
    DEPOSIT = "DEPOSIT",
    FACOTRING = "FACOTRING"
}
export declare enum AccountSubType {
    "INSTALLMENT LOAN" = "INSTALLMENT LOAN",
    "REVOLVING CREDIT" = "REVOLVING CREDIT",
    "RECOURSE" = "RECOURSE",
    "NON-RECOURSE" = "NON-RECOURSE",
    "ADMIN" = "ADMIN",
    "HYBRID" = "HYBRID"
}
export declare const reserveAccountQuerySchema: z.ZodObject<{
    sourceSystemCode: z.ZodString;
    sourceApplicationId: z.ZodString;
    accountTypeCode: z.ZodNativeEnum<typeof AccountType>;
    accountSubtypeCode: z.ZodNativeEnum<typeof AccountSubType>;
}, "strip", z.ZodTypeAny, {
    sourceSystemCode: string;
    sourceApplicationId: string;
    accountTypeCode: AccountType;
    accountSubtypeCode: AccountSubType;
}, {
    sourceSystemCode: string;
    sourceApplicationId: string;
    accountTypeCode: AccountType;
    accountSubtypeCode: AccountSubType;
}>;
export type ReserveAccountQueryRequest = z.infer<typeof reserveAccountQuerySchema>;
export interface ReserveAccountResponse {
    correlationId: string;
    result: boolean;
    resultNewAccountNo: string;
    serviceVersion: string;
}
export declare const uploadDocumentToAccountReservationParamsSchema: z.ZodObject<{
    accountNo: z.ZodString;
}, "strip", z.ZodTypeAny, {
    accountNo: string;
}, {
    accountNo: string;
}>;
export declare const uploadDocumentToAccountReservationBodySchema: z.ZodObject<{
    sourceDocumentGUID: z.ZodOptional<z.ZodString>;
    documentType: z.ZodOptional<z.ZodString>;
    documentTitle: z.ZodString;
    documentURL: z.ZodOptional<z.ZodString>;
    documentContent: z.ZodString;
    documentContentFileType: z.ZodString;
    showInMyPage: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    documentTitle: string;
    documentContent: string;
    documentContentFileType: string;
    showInMyPage: boolean;
    sourceDocumentGUID?: string | undefined;
    documentType?: string | undefined;
    documentURL?: string | undefined;
}, {
    documentTitle: string;
    documentContent: string;
    documentContentFileType: string;
    showInMyPage: boolean;
    sourceDocumentGUID?: string | undefined;
    documentType?: string | undefined;
    documentURL?: string | undefined;
}>;
export type UploadDocumentToAccountReservationBodySchema = z.infer<typeof uploadDocumentToAccountReservationBodySchema>;
export interface UploadDocumentToAccountReservationResponse {
    correlationId: string;
    result: boolean;
    serviceVersion: string;
}
export declare const createAccountQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
}, "strip", z.ZodTypeAny, {
    countryIds: string;
    businessAreaIds: string;
    correlationId?: string | undefined;
}, {
    countryIds: string;
    businessAreaIds: string;
    correlationId?: string | undefined;
}>;
export declare const getAccountQuerySchema: z.ZodObject<{
    nationalId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    nationalId: string;
}, {
    nationalId: string;
}>;
export type CreateAccountQueryRequest = z.infer<typeof createAccountQuerySchema>;
export declare const TransactionListQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
    legalId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    countryIds: string;
    businessAreaIds: string;
    legalId: string;
    correlationId?: string | undefined;
}, {
    countryIds: string;
    businessAreaIds: string;
    legalId: string;
    correlationId?: string | undefined;
}>;
export type TransactionListQueryRequest = z.infer<typeof TransactionListQuerySchema>;
export declare const LedgerListQuerySchema: z.ZodObject<{
    correlationId: z.ZodOptional<z.ZodString>;
    countryIds: z.ZodString;
    businessAreaIds: z.ZodString;
    legalId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    countryIds: string;
    businessAreaIds: string;
    legalId: string;
    correlationId?: string | undefined;
}, {
    countryIds: string;
    businessAreaIds: string;
    legalId: string;
    correlationId?: string | undefined;
}>;
export type LedgerListQueryRequest = z.infer<typeof LedgerListQuerySchema>;
export interface LedgerListRepose {
    correlationId: string;
    resultCustLedger: {
        accountNo: string;
        customerLedgerEntry: [
            {
                entryNo: number;
                customerNo: string;
                postingDate: string;
                amount: number;
                remainingAmount: number;
                reversed: string;
                bankAccountNo: string;
                paymentReference: string;
                dueDate: string;
                documentType: string;
                documentNo: string;
                open: boolean;
                reminderLevel: number;
                collectorsReferenceNo: string;
            }
        ];
        custLedgerCount: number;
    };
    serviceVersion: string;
    result: boolean;
}
export interface TransactionListResponse {
    correlationId: string;
    result: boolean;
    resultSystemCurrencyCode: string;
    resultTransactions: {
        transactions: [
            {
                lineNo: number;
                lineType: string;
                documentType: string;
                reasonCode: string;
                documentNo: string;
                specificationType: string;
                bookDate: string;
                transactionSource: string;
                transactionID: number;
                transactionType: string;
                sourceTransactionID: string;
                transactionDate: string;
                dueDate: string;
                amount: number;
                runningTotalAfterTrans: number;
                description: string;
                productCode: string;
            }
        ];
        transactionsCount: number;
    };
    serviceVersion: string;
}
export interface SecurityInfo {
    coreSecurityNo: string;
    securityFaceValue: number;
    precedingCollateral: boolean;
    priorityAmount: number;
    type: string;
    coreContactNo: string;
    coreContactName: string;
    registrationDocumentNo: string;
    registrationDocumentYear: string;
    registrationOfficeNo: string;
    registrationRightNo: string;
    objectInfo: ObjectInfo[];
}
export interface AdditionalProduct {
    agreementNo: number;
    productCode: string;
    description: string;
    invoiceDescription: string;
    startDate: Date;
    stopDate: Date;
    price: number;
}
export interface ObjectInfo {
    coreObjectNo: string;
    objectPropertyAddress: string;
    objectPropertyZip: string;
    objectPropertyLandNo: string;
    objectPropertyLeaseNo: string;
    objectPropertyMunicipalNo: string;
    objectPropertyOrgNo: string;
    objectPropertySectionNo: string;
    objectPropertyShareNo: string;
    objectPropertyUnitNo: string;
    objectSubClassCode: string;
    depotLastValuationDate: Date;
    depotAdjustmentSource: string;
    depotValidUntil: string;
    depotMunicipalityScore: number;
    depotAreaScore: number;
    depotAreaVacationScore: number;
    depotCommonDebt: number;
    depotCommonDebtDate: Date;
    depotDepreciationFactor: number;
    depotValue: number;
    depotValueFactor: number;
    objectClassCode: string;
    objectConditionCode: number;
    activeDebtStatement: boolean;
    ltvRatio: number;
    objectContacts: {
        contactSSN: string;
        coreContactNo: string;
        ownerShare: number;
    }[];
}
export interface AccountInfo {
    sourceApplicationID: string;
    mainContactLegalID: string;
    loanType: string;
    openForRevolving: boolean;
    originalTermLength: number;
    currentTermLength: number;
    accountEndDate: Date;
    sourceSystemCode: string;
    sourceApplicationId: string;
    accountNo: string;
    currencyCode: string;
    mainContactNo: string;
    mainContactLegalId: string;
    mainContactName: string;
    coSignerContactNo: string;
    coSignerLegalID: string;
    coSignerName: string;
    sourceMainContactID: string;
    sourceCoSignerContactID: string;
    accountType: string;
    accountSubtype: string;
    accountDescription: string;
    externalProductID: string;
    accountStatusGroup: "NY" | "LØPENDE" | "INKASSO" | "AVSLUTTET" | string;
    accountStatus: string;
    initialNetLoanAmount: number;
    interestRate: number;
    effectiveRate: number;
    currentEffectiveRate: number;
    bookedBalance: number;
    principalBalance: number;
    openPrincipalPaymentBalance: number;
    availableBalance: number;
    accruedInterest: number;
    ongoingPayout: number;
    openForRevoling: boolean;
    creditLimitAmount: number;
    usedCreditAmount: number;
    totalSecurityFaceValue: number;
    remainingTerms: number;
    nextDueDate: Date;
    nextTermAmount: number;
    nextTermMinAmount: number;
    nextTermFee: number;
    nextTermLengthInMonths: number;
    balanceDue: number;
    startDate: Date;
    nextAddProductAmount: number;
    custBalanceOnCustomer: number;
    custBalanceDueOnCustomer: number;
    custBalanceOnClient: number;
    custBalanceFinancedOnClient: number;
    payInBBAN: string;
    payInIBAN: string;
    payInKID: string;
    paymentBankAccountNo: string;
    disbursementBankAccountNo: string;
    replacedBy: string;
    replaces: string;
    securityInfo: SecurityInfo[];
    additionalProduct: AdditionalProduct[];
    document: Document[];
    ltvRatio: number;
    additionalNextInvoice: number;
}
export interface Document {
    type: string;
    entryNo: number;
    guid: string;
    apiReference: string;
    sourceGuid: string;
    title: string;
    url: string;
    contentTypeCode: string;
    uploadedViaCore: boolean;
    hasContentInCore: boolean;
}
export interface AccountListResponse {
    correlationId: string;
    resultAccountList: {
        accountInfo: AccountInfo[];
        accountInfoCount: number;
    };
    serviceVersion: string;
    result: boolean;
}
export interface AccountDetailsResponse {
    correlationId: string;
    resultAccountDetails: {
        accountInfo: AccountInfo[];
        accountInfoCount: number;
    };
    serviceVersion: string;
    result: boolean;
}
export declare const createAccountRequestSchema: z.ZodObject<{
    newAccountApplication: z.ZodObject<{
        account: z.ZodObject<{
            sourceSystemCode: z.ZodString;
            sourceApplicationID: z.ZodString;
            accountTypeCode: z.ZodNativeEnum<typeof AccountType>;
            accountSubtypeCode: z.ZodNativeEnum<typeof AccountSubType>;
            originationDate: z.ZodEffects<z.ZodString, string, string>;
            startDate: z.ZodEffects<z.ZodString, string, string>;
            contractTypeCode: z.ZodOptional<z.ZodString>;
            limitAmount: z.ZodOptional<z.ZodNumber>;
            limitExpiryDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            dueDay: z.ZodNumber;
            interestGroupCode: z.ZodString;
            baseInterestRate: z.ZodOptional<z.ZodNumber>;
            nominalInterestRate: z.ZodNumber;
            netLoanAmount: z.ZodNumber;
            objectPrice: z.ZodNumber;
            equityAmount: z.ZodOptional<z.ZodNumber>;
            vatRate: z.ZodOptional<z.ZodNumber>;
            vatAmount: z.ZodOptional<z.ZodNumber>;
            contractDocTitle: z.ZodOptional<z.ZodString>;
            contractDocURL: z.ZodOptional<z.ZodString>;
            requireDirectDebit: z.ZodOptional<z.ZodBoolean>;
            directDebitAccountNo: z.ZodOptional<z.ZodString>;
            directDebitAmountLimit: z.ZodOptional<z.ZodNumber>;
            initiateDirectDebit: z.ZodOptional<z.ZodBoolean>;
            iban: z.ZodOptional<z.ZodString>;
            factoringInvoiceLimit: z.ZodOptional<z.ZodNumber>;
            disbursementBankAccountNo: z.ZodOptional<z.ZodString>;
            principalFreeTerms: z.ZodOptional<z.ZodNumber>;
            transparencyCode: z.ZodOptional<z.ZodEnum<["ANSATTE", "VIP"]>>;
            tag: z.ZodOptional<z.ZodArray<z.ZodObject<{
                tagCode: z.ZodString;
                description: z.ZodOptional<z.ZodString>;
                expireDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            }, "strict", z.ZodTypeAny, {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }, {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }>, "many">>;
        }, "strict", z.ZodTypeAny, {
            interestGroupCode: string;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            principalFreeTerms?: number | undefined;
            transparencyCode?: "ANSATTE" | "VIP" | undefined;
            tag?: {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
        }, {
            interestGroupCode: string;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            principalFreeTerms?: number | undefined;
            transparencyCode?: "ANSATTE" | "VIP" | undefined;
            tag?: {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
        }>;
        accountDimension: z.ZodOptional<z.ZodArray<z.ZodObject<{
            dimensionCode: z.ZodString;
            dimensionValue: z.ZodString;
            dimensionDescription: z.ZodString;
        }, "strict", z.ZodTypeAny, {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }, {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }>, "many">>;
        product: z.ZodObject<{
            sourceProductID: z.ZodString;
        }, "strict", z.ZodTypeAny, {
            sourceProductID: string;
        }, {
            sourceProductID: string;
        }>;
        paymentSeries: z.ZodArray<z.ZodObject<{
            legNo: z.ZodNumber;
            termLength: z.ZodNumber;
            termCount: z.ZodNumber;
            minAmountTermCount: z.ZodOptional<z.ZodNumber>;
            minAmountTermCountMax: z.ZodOptional<z.ZodNumber>;
            rateType: z.ZodNativeEnum<typeof RateType>;
            termDue: z.ZodOptional<z.ZodNumber>;
            amortization: z.ZodNativeEnum<typeof Amortization>;
            interestRate: z.ZodNumber;
            startBalance: z.ZodNumber;
            endBalance: z.ZodNumber;
            termFee: z.ZodNumber;
            netTermAmount: z.ZodOptional<z.ZodNumber>;
            grossTermAmount: z.ZodOptional<z.ZodNumber>;
        }, "strict", z.ZodTypeAny, {
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
        }, {
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
        }>, "many">;
        contact: z.ZodArray<z.ZodObject<{
            sourceContactID: z.ZodString;
            contactRoleCode: z.ZodEnum<["SIGNER", "COSIGNER", "GUARANTOR", "VENDOR", "BROKER", "SALESPERSON", "INTERNALUNDERWRITER", "INTERNALSALESPERSON", "REPURCHASER", "SUPPLIER", "INSURANCE", "CONTACTPERSON", "UBO", "POA", "OTHER"]>;
            otherRole: z.ZodOptional<z.ZodString>;
            accountShare: z.ZodOptional<z.ZodNumber>;
            organizationNo: z.ZodOptional<z.ZodString>;
            socialSecurityNo: z.ZodString;
            dateOfBirthOrReg: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            sectorCode: z.ZodOptional<z.ZodString>;
            economicActivityCode: z.ZodOptional<z.ZodString>;
            legalEntityTypeCode: z.ZodOptional<z.ZodString>;
            companyName: z.ZodOptional<z.ZodString>;
            firstName: z.ZodString;
            middleName: z.ZodString;
            surname: z.ZodString;
            salutationCode: z.ZodOptional<z.ZodString>;
            jobTitle: z.ZodOptional<z.ZodString>;
            eMail: z.ZodString;
            invoiceEMail: z.ZodOptional<z.ZodString>;
            reminderEMail: z.ZodOptional<z.ZodString>;
            phoneNo: z.ZodOptional<z.ZodString>;
            mobilePhoneNo: z.ZodString;
            nationalityCode: z.ZodString;
            address: z.ZodString;
            address2: z.ZodOptional<z.ZodString>;
            streetType: z.ZodOptional<z.ZodString>;
            postCode: z.ZodString;
            city: z.ZodString;
            region: z.ZodOptional<z.ZodString>;
            countryCode: z.ZodString;
            languageCode: z.ZodString;
            optOutOfEcommunication: z.ZodOptional<z.ZodBoolean>;
            emarketing: z.ZodOptional<z.ZodBoolean>;
            guarantorType: z.ZodOptional<z.ZodString>;
            guarantorAmount: z.ZodOptional<z.ZodNumber>;
            guarantorExpiryDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            pep: z.ZodNumber;
            riskLevelAML: z.ZodNumber;
            citizenshipCode: z.ZodArray<z.ZodString, "many">;
            kycAnswer: z.ZodOptional<z.ZodArray<z.ZodObject<{
                questionID: z.ZodString;
                answer: z.ZodString;
                timestamp: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }, {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }>, "many">>;
            dateOfLastKYC: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            contactPreferences: z.ZodOptional<z.ZodObject<{
                eCommunication: z.ZodOptional<z.ZodBoolean>;
                eMarketing: z.ZodOptional<z.ZodBoolean>;
                eMarketingSms: z.ZodOptional<z.ZodBoolean>;
                eMarketingEmail: z.ZodOptional<z.ZodBoolean>;
                text: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            }, "strip", z.ZodTypeAny, {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            }, {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            }>>;
        }, "strict", z.ZodTypeAny, {
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: string;
            address: string;
            postCode: string;
            city: string;
            countryCode: string;
            languageCode: string;
            pep: number;
            riskLevelAML: number;
            citizenshipCode: string[];
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            optOutOfEcommunication?: boolean | undefined;
            emarketing?: boolean | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            contactPreferences?: {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            } | undefined;
        }, {
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: string;
            address: string;
            postCode: string;
            city: string;
            countryCode: string;
            languageCode: string;
            pep: number;
            riskLevelAML: number;
            citizenshipCode: string[];
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            optOutOfEcommunication?: boolean | undefined;
            emarketing?: boolean | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            contactPreferences?: {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            } | undefined;
        }>, "many">;
        disbursement: z.ZodArray<z.ZodObject<{
            sourceDisbursementID: z.ZodOptional<z.ZodString>;
            recipientType: z.ZodEnum<["CUSTOMER", "VENDOR", "INTERNALACCOUNT"]>;
            coreAccountNo: z.ZodOptional<z.ZodString>;
            bankAccountNo: z.ZodOptional<z.ZodString>;
            paymentDate: z.ZodEffects<z.ZodString, string, string>;
            currency: z.ZodOptional<z.ZodString>;
            amount: z.ZodNumber;
            paymentReference: z.ZodOptional<z.ZodString>;
            paymentText: z.ZodOptional<z.ZodString>;
        }, "strict", z.ZodTypeAny, {
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            sourceDisbursementID?: string | undefined;
            coreAccountNo?: string | undefined;
            bankAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            paymentText?: string | undefined;
        }, {
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            sourceDisbursementID?: string | undefined;
            coreAccountNo?: string | undefined;
            bankAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            paymentText?: string | undefined;
        }>, "many">;
        fee: z.ZodArray<z.ZodObject<{
            sourceFeeID: z.ZodOptional<z.ZodString>;
            feeTypeCode: z.ZodOptional<z.ZodString>;
            feeCode: z.ZodString;
            feeAmountType: z.ZodOptional<z.ZodString>;
            feeAmount: z.ZodNumber;
            feeValueType: z.ZodOptional<z.ZodString>;
            feeValue: z.ZodOptional<z.ZodNumber>;
            includeInInterestCalc: z.ZodBoolean;
            feeIsFinanced: z.ZodBoolean;
        }, "strict", z.ZodTypeAny, {
            feeCode: string;
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
        }, {
            feeCode: string;
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
        }>, "many">;
        brand: z.ZodArray<z.ZodObject<{
            brandCode: z.ZodString;
            brandOrgNo: z.ZodOptional<z.ZodString>;
            brandCompany: z.ZodOptional<z.ZodString>;
        }, "strict", z.ZodTypeAny, {
            brandCode: string;
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
        }, {
            brandCode: string;
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
        }>, "many">;
        additionalProduct: z.ZodOptional<z.ZodArray<z.ZodObject<{
            productCode: z.ZodString;
            startDate: z.ZodEffects<z.ZodString, string, string>;
            endDate: z.ZodEffects<z.ZodString, string, string>;
            priceCalcType: z.ZodString;
            priceCalcValue: z.ZodNumber;
            consentDate: z.ZodEffects<z.ZodString, string, string>;
            freeTerms: z.ZodNumber;
            minimumPrice: z.ZodNumber;
        }, "strict", z.ZodTypeAny, {
            productCode: string;
            startDate: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }, {
            productCode: string;
            startDate: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }>, "many">>;
        object: z.ZodArray<z.ZodObject<{
            coreObjectNo: z.ZodString;
            sourceObjectID: z.ZodString;
            objectIdNumber: z.ZodOptional<z.ZodString>;
            objectDescription: z.ZodString;
            objectDescriptionLong: z.ZodOptional<z.ZodString>;
            objectMake: z.ZodOptional<z.ZodString>;
            objectModel: z.ZodOptional<z.ZodString>;
            objectEngine: z.ZodOptional<z.ZodString>;
            objectYear: z.ZodOptional<z.ZodNumber>;
            objectIsFinanced: z.ZodOptional<z.ZodBoolean>;
            installationInfo: z.ZodOptional<z.ZodString>;
            insuranceName: z.ZodOptional<z.ZodString>;
            insuranceOrgNo: z.ZodOptional<z.ZodString>;
            insurancePolicyNo: z.ZodOptional<z.ZodString>;
            insuranceInfo: z.ZodOptional<z.ZodString>;
            objectGroupCode: z.ZodOptional<z.ZodString>;
            objectSubgroupCode: z.ZodOptional<z.ZodString>;
            objectConditionCode: z.ZodOptional<z.ZodNumber>;
            depotValue: z.ZodNumber;
            depotDate: z.ZodEffects<z.ZodString, string, string>;
            depotPropertyCommonDebt: z.ZodOptional<z.ZodNumber>;
            depotPropertyCommonDebtDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            depotPropertyAreaScore: z.ZodNumber;
            depotPropertyMunicipalityScore: z.ZodNumber;
            depotPropertyAreaVactionScore: z.ZodNumber;
            objectPropertyAddress: z.ZodString;
            objectPropertyZip: z.ZodString;
            objectPropertyLandNo: z.ZodOptional<z.ZodString>;
            objectPropertyUnitNo: z.ZodOptional<z.ZodString>;
            objectPropertyMunicipalNo: z.ZodOptional<z.ZodString>;
            objectPropertyLeaseNo: z.ZodOptional<z.ZodString>;
            objectPropertySectionNo: z.ZodOptional<z.ZodString>;
            objectPropertyOrganizationNo: z.ZodOptional<z.ZodString>;
            objectPropertyShareNo: z.ZodOptional<z.ZodString>;
            propertyLevelCode: z.ZodOptional<z.ZodString>;
            objectContacts: z.ZodArray<z.ZodObject<{
                sourceContactID: z.ZodString;
                ownerShare: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                sourceContactID: string;
                ownerShare: number;
            }, {
                sourceContactID: string;
                ownerShare: number;
            }>, "many">;
        }, "strict", z.ZodTypeAny, {
            coreObjectNo: string;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
            depotDate: string;
            depotPropertyAreaScore: number;
            depotPropertyMunicipalityScore: number;
            depotPropertyAreaVactionScore: number;
            objectPropertyAddress: string;
            objectPropertyZip: string;
            objectContacts: {
                sourceContactID: string;
                ownerShare: number;
            }[];
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotPropertyCommonDebt?: number | undefined;
            depotPropertyCommonDebtDate?: string | undefined;
            objectPropertyLandNo?: string | undefined;
            objectPropertyUnitNo?: string | undefined;
            objectPropertyMunicipalNo?: string | undefined;
            objectPropertyLeaseNo?: string | undefined;
            objectPropertySectionNo?: string | undefined;
            objectPropertyOrganizationNo?: string | undefined;
            objectPropertyShareNo?: string | undefined;
            propertyLevelCode?: string | undefined;
        }, {
            coreObjectNo: string;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
            depotDate: string;
            depotPropertyAreaScore: number;
            depotPropertyMunicipalityScore: number;
            depotPropertyAreaVactionScore: number;
            objectPropertyAddress: string;
            objectPropertyZip: string;
            objectContacts: {
                sourceContactID: string;
                ownerShare: number;
            }[];
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotPropertyCommonDebt?: number | undefined;
            depotPropertyCommonDebtDate?: string | undefined;
            objectPropertyLandNo?: string | undefined;
            objectPropertyUnitNo?: string | undefined;
            objectPropertyMunicipalNo?: string | undefined;
            objectPropertyLeaseNo?: string | undefined;
            objectPropertySectionNo?: string | undefined;
            objectPropertyOrganizationNo?: string | undefined;
            objectPropertyShareNo?: string | undefined;
            propertyLevelCode?: string | undefined;
        }>, "many">;
        security: z.ZodArray<z.ZodObject<{
            coreSecurityID: z.ZodOptional<z.ZodString>;
            sourceSecurityID: z.ZodOptional<z.ZodString>;
            sourceObjectID: z.ZodOptional<z.ZodString>;
            securityTypeCode: z.ZodOptional<z.ZodString>;
            securityTypeText: z.ZodOptional<z.ZodString>;
            securityFaceValue: z.ZodOptional<z.ZodNumber>;
            securityExpirationDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            securityOrderOfPriority: z.ZodOptional<z.ZodNumber>;
            securityPriorityAmount: z.ZodOptional<z.ZodNumber>;
            securityDescription: z.ZodOptional<z.ZodString>;
            securityRegistrationDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            registrationDocumentNo: z.ZodOptional<z.ZodString>;
            registrationDocumentYear: z.ZodOptional<z.ZodString>;
            registrationOfficeNo: z.ZodOptional<z.ZodString>;
            registrationRightNo: z.ZodOptional<z.ZodString>;
            securityExternal: z.ZodOptional<z.ZodBoolean>;
            securityExternalFaceValue: z.ZodOptional<z.ZodNumber>;
            securityExternalPart: z.ZodOptional<z.ZodString>;
            securityContacts: z.ZodOptional<z.ZodArray<z.ZodObject<{
                sourceContactID: z.ZodString;
                ownerShare: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                sourceContactID: string;
                ownerShare: number;
            }, {
                sourceContactID: string;
                ownerShare: number;
            }>, "many">>;
            tag: z.ZodOptional<z.ZodArray<z.ZodObject<{
                tagCode: z.ZodString;
                description: z.ZodOptional<z.ZodString>;
                expireDate: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
                sourceSecurityID: z.ZodString;
            }, "strict", z.ZodTypeAny, {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }, {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }>, "many">>;
        }, "strict", z.ZodTypeAny, {
            tag?: {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
            sourceObjectID?: string | undefined;
            coreSecurityID?: string | undefined;
            sourceSecurityID?: string | undefined;
            securityTypeCode?: string | undefined;
            securityTypeText?: string | undefined;
            securityFaceValue?: number | undefined;
            securityExpirationDate?: string | undefined;
            securityOrderOfPriority?: number | undefined;
            securityPriorityAmount?: number | undefined;
            securityDescription?: string | undefined;
            securityRegistrationDate?: string | undefined;
            registrationDocumentNo?: string | undefined;
            registrationDocumentYear?: string | undefined;
            registrationOfficeNo?: string | undefined;
            registrationRightNo?: string | undefined;
            securityExternal?: boolean | undefined;
            securityExternalFaceValue?: number | undefined;
            securityExternalPart?: string | undefined;
            securityContacts?: {
                sourceContactID: string;
                ownerShare: number;
            }[] | undefined;
        }, {
            tag?: {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
            sourceObjectID?: string | undefined;
            coreSecurityID?: string | undefined;
            sourceSecurityID?: string | undefined;
            securityTypeCode?: string | undefined;
            securityTypeText?: string | undefined;
            securityFaceValue?: number | undefined;
            securityExpirationDate?: string | undefined;
            securityOrderOfPriority?: number | undefined;
            securityPriorityAmount?: number | undefined;
            securityDescription?: string | undefined;
            securityRegistrationDate?: string | undefined;
            registrationDocumentNo?: string | undefined;
            registrationDocumentYear?: string | undefined;
            registrationOfficeNo?: string | undefined;
            registrationRightNo?: string | undefined;
            securityExternal?: boolean | undefined;
            securityExternalFaceValue?: number | undefined;
            securityExternalPart?: string | undefined;
            securityContacts?: {
                sourceContactID: string;
                ownerShare: number;
            }[] | undefined;
        }>, "many">;
        securityObject: z.ZodArray<z.ZodObject<{
            sourceObjectID: z.ZodString;
            sourceSecurityID: z.ZodString;
            priority: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            sourceObjectID: string;
            sourceSecurityID: string;
            priority?: number | undefined;
        }, {
            sourceObjectID: string;
            sourceSecurityID: string;
            priority?: number | undefined;
        }>, "many">;
        accountDocument: z.ZodArray<z.ZodObject<{
            sentForReservation: z.ZodOptional<z.ZodBoolean>;
            sourceDocumentGUID: z.ZodOptional<z.ZodString>;
            documentType: z.ZodString;
            documentTitle: z.ZodString;
            documentURL: z.ZodString;
            documentContent: z.ZodOptional<z.ZodString>;
            documentContentFileType: z.ZodOptional<z.ZodString>;
            showInMyPage: z.ZodOptional<z.ZodBoolean>;
        }, "strict", z.ZodTypeAny, {
            documentType: string;
            documentTitle: string;
            documentURL: string;
            sourceDocumentGUID?: string | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            showInMyPage?: boolean | undefined;
            sentForReservation?: boolean | undefined;
        }, {
            documentType: string;
            documentTitle: string;
            documentURL: string;
            sourceDocumentGUID?: string | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            showInMyPage?: boolean | undefined;
            sentForReservation?: boolean | undefined;
        }>, "many">;
        text: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        object: {
            coreObjectNo: string;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
            depotDate: string;
            depotPropertyAreaScore: number;
            depotPropertyMunicipalityScore: number;
            depotPropertyAreaVactionScore: number;
            objectPropertyAddress: string;
            objectPropertyZip: string;
            objectContacts: {
                sourceContactID: string;
                ownerShare: number;
            }[];
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotPropertyCommonDebt?: number | undefined;
            depotPropertyCommonDebtDate?: string | undefined;
            objectPropertyLandNo?: string | undefined;
            objectPropertyUnitNo?: string | undefined;
            objectPropertyMunicipalNo?: string | undefined;
            objectPropertyLeaseNo?: string | undefined;
            objectPropertySectionNo?: string | undefined;
            objectPropertyOrganizationNo?: string | undefined;
            objectPropertyShareNo?: string | undefined;
            propertyLevelCode?: string | undefined;
        }[];
        account: {
            interestGroupCode: string;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            principalFreeTerms?: number | undefined;
            transparencyCode?: "ANSATTE" | "VIP" | undefined;
            tag?: {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
        };
        product: {
            sourceProductID: string;
        };
        paymentSeries: {
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
        }[];
        contact: {
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: string;
            address: string;
            postCode: string;
            city: string;
            countryCode: string;
            languageCode: string;
            pep: number;
            riskLevelAML: number;
            citizenshipCode: string[];
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            optOutOfEcommunication?: boolean | undefined;
            emarketing?: boolean | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            contactPreferences?: {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            } | undefined;
        }[];
        disbursement: {
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            sourceDisbursementID?: string | undefined;
            coreAccountNo?: string | undefined;
            bankAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            paymentText?: string | undefined;
        }[];
        fee: {
            feeCode: string;
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
        }[];
        brand: {
            brandCode: string;
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
        }[];
        security: {
            tag?: {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
            sourceObjectID?: string | undefined;
            coreSecurityID?: string | undefined;
            sourceSecurityID?: string | undefined;
            securityTypeCode?: string | undefined;
            securityTypeText?: string | undefined;
            securityFaceValue?: number | undefined;
            securityExpirationDate?: string | undefined;
            securityOrderOfPriority?: number | undefined;
            securityPriorityAmount?: number | undefined;
            securityDescription?: string | undefined;
            securityRegistrationDate?: string | undefined;
            registrationDocumentNo?: string | undefined;
            registrationDocumentYear?: string | undefined;
            registrationOfficeNo?: string | undefined;
            registrationRightNo?: string | undefined;
            securityExternal?: boolean | undefined;
            securityExternalFaceValue?: number | undefined;
            securityExternalPart?: string | undefined;
            securityContacts?: {
                sourceContactID: string;
                ownerShare: number;
            }[] | undefined;
        }[];
        securityObject: {
            sourceObjectID: string;
            sourceSecurityID: string;
            priority?: number | undefined;
        }[];
        accountDocument: {
            documentType: string;
            documentTitle: string;
            documentURL: string;
            sourceDocumentGUID?: string | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            showInMyPage?: boolean | undefined;
            sentForReservation?: boolean | undefined;
        }[];
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        text?: string[] | undefined;
        additionalProduct?: {
            productCode: string;
            startDate: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
    }, {
        object: {
            coreObjectNo: string;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
            depotDate: string;
            depotPropertyAreaScore: number;
            depotPropertyMunicipalityScore: number;
            depotPropertyAreaVactionScore: number;
            objectPropertyAddress: string;
            objectPropertyZip: string;
            objectContacts: {
                sourceContactID: string;
                ownerShare: number;
            }[];
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotPropertyCommonDebt?: number | undefined;
            depotPropertyCommonDebtDate?: string | undefined;
            objectPropertyLandNo?: string | undefined;
            objectPropertyUnitNo?: string | undefined;
            objectPropertyMunicipalNo?: string | undefined;
            objectPropertyLeaseNo?: string | undefined;
            objectPropertySectionNo?: string | undefined;
            objectPropertyOrganizationNo?: string | undefined;
            objectPropertyShareNo?: string | undefined;
            propertyLevelCode?: string | undefined;
        }[];
        account: {
            interestGroupCode: string;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            principalFreeTerms?: number | undefined;
            transparencyCode?: "ANSATTE" | "VIP" | undefined;
            tag?: {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
        };
        product: {
            sourceProductID: string;
        };
        paymentSeries: {
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
        }[];
        contact: {
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: string;
            address: string;
            postCode: string;
            city: string;
            countryCode: string;
            languageCode: string;
            pep: number;
            riskLevelAML: number;
            citizenshipCode: string[];
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            optOutOfEcommunication?: boolean | undefined;
            emarketing?: boolean | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            contactPreferences?: {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            } | undefined;
        }[];
        disbursement: {
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            sourceDisbursementID?: string | undefined;
            coreAccountNo?: string | undefined;
            bankAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            paymentText?: string | undefined;
        }[];
        fee: {
            feeCode: string;
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
        }[];
        brand: {
            brandCode: string;
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
        }[];
        security: {
            tag?: {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
            sourceObjectID?: string | undefined;
            coreSecurityID?: string | undefined;
            sourceSecurityID?: string | undefined;
            securityTypeCode?: string | undefined;
            securityTypeText?: string | undefined;
            securityFaceValue?: number | undefined;
            securityExpirationDate?: string | undefined;
            securityOrderOfPriority?: number | undefined;
            securityPriorityAmount?: number | undefined;
            securityDescription?: string | undefined;
            securityRegistrationDate?: string | undefined;
            registrationDocumentNo?: string | undefined;
            registrationDocumentYear?: string | undefined;
            registrationOfficeNo?: string | undefined;
            registrationRightNo?: string | undefined;
            securityExternal?: boolean | undefined;
            securityExternalFaceValue?: number | undefined;
            securityExternalPart?: string | undefined;
            securityContacts?: {
                sourceContactID: string;
                ownerShare: number;
            }[] | undefined;
        }[];
        securityObject: {
            sourceObjectID: string;
            sourceSecurityID: string;
            priority?: number | undefined;
        }[];
        accountDocument: {
            documentType: string;
            documentTitle: string;
            documentURL: string;
            sourceDocumentGUID?: string | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            showInMyPage?: boolean | undefined;
            sentForReservation?: boolean | undefined;
        }[];
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        text?: string[] | undefined;
        additionalProduct?: {
            productCode: string;
            startDate: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    newAccountApplication: {
        object: {
            coreObjectNo: string;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
            depotDate: string;
            depotPropertyAreaScore: number;
            depotPropertyMunicipalityScore: number;
            depotPropertyAreaVactionScore: number;
            objectPropertyAddress: string;
            objectPropertyZip: string;
            objectContacts: {
                sourceContactID: string;
                ownerShare: number;
            }[];
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotPropertyCommonDebt?: number | undefined;
            depotPropertyCommonDebtDate?: string | undefined;
            objectPropertyLandNo?: string | undefined;
            objectPropertyUnitNo?: string | undefined;
            objectPropertyMunicipalNo?: string | undefined;
            objectPropertyLeaseNo?: string | undefined;
            objectPropertySectionNo?: string | undefined;
            objectPropertyOrganizationNo?: string | undefined;
            objectPropertyShareNo?: string | undefined;
            propertyLevelCode?: string | undefined;
        }[];
        account: {
            interestGroupCode: string;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            principalFreeTerms?: number | undefined;
            transparencyCode?: "ANSATTE" | "VIP" | undefined;
            tag?: {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
        };
        product: {
            sourceProductID: string;
        };
        paymentSeries: {
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
        }[];
        contact: {
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: string;
            address: string;
            postCode: string;
            city: string;
            countryCode: string;
            languageCode: string;
            pep: number;
            riskLevelAML: number;
            citizenshipCode: string[];
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            optOutOfEcommunication?: boolean | undefined;
            emarketing?: boolean | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            contactPreferences?: {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            } | undefined;
        }[];
        disbursement: {
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            sourceDisbursementID?: string | undefined;
            coreAccountNo?: string | undefined;
            bankAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            paymentText?: string | undefined;
        }[];
        fee: {
            feeCode: string;
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
        }[];
        brand: {
            brandCode: string;
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
        }[];
        security: {
            tag?: {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
            sourceObjectID?: string | undefined;
            coreSecurityID?: string | undefined;
            sourceSecurityID?: string | undefined;
            securityTypeCode?: string | undefined;
            securityTypeText?: string | undefined;
            securityFaceValue?: number | undefined;
            securityExpirationDate?: string | undefined;
            securityOrderOfPriority?: number | undefined;
            securityPriorityAmount?: number | undefined;
            securityDescription?: string | undefined;
            securityRegistrationDate?: string | undefined;
            registrationDocumentNo?: string | undefined;
            registrationDocumentYear?: string | undefined;
            registrationOfficeNo?: string | undefined;
            registrationRightNo?: string | undefined;
            securityExternal?: boolean | undefined;
            securityExternalFaceValue?: number | undefined;
            securityExternalPart?: string | undefined;
            securityContacts?: {
                sourceContactID: string;
                ownerShare: number;
            }[] | undefined;
        }[];
        securityObject: {
            sourceObjectID: string;
            sourceSecurityID: string;
            priority?: number | undefined;
        }[];
        accountDocument: {
            documentType: string;
            documentTitle: string;
            documentURL: string;
            sourceDocumentGUID?: string | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            showInMyPage?: boolean | undefined;
            sentForReservation?: boolean | undefined;
        }[];
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        text?: string[] | undefined;
        additionalProduct?: {
            productCode: string;
            startDate: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
    };
}, {
    newAccountApplication: {
        object: {
            coreObjectNo: string;
            sourceObjectID: string;
            objectDescription: string;
            depotValue: number;
            depotDate: string;
            depotPropertyAreaScore: number;
            depotPropertyMunicipalityScore: number;
            depotPropertyAreaVactionScore: number;
            objectPropertyAddress: string;
            objectPropertyZip: string;
            objectContacts: {
                sourceContactID: string;
                ownerShare: number;
            }[];
            objectIdNumber?: string | undefined;
            objectDescriptionLong?: string | undefined;
            objectMake?: string | undefined;
            objectModel?: string | undefined;
            objectEngine?: string | undefined;
            objectYear?: number | undefined;
            objectIsFinanced?: boolean | undefined;
            installationInfo?: string | undefined;
            insuranceName?: string | undefined;
            insuranceOrgNo?: string | undefined;
            insurancePolicyNo?: string | undefined;
            insuranceInfo?: string | undefined;
            objectGroupCode?: string | undefined;
            objectSubgroupCode?: string | undefined;
            objectConditionCode?: number | undefined;
            depotPropertyCommonDebt?: number | undefined;
            depotPropertyCommonDebtDate?: string | undefined;
            objectPropertyLandNo?: string | undefined;
            objectPropertyUnitNo?: string | undefined;
            objectPropertyMunicipalNo?: string | undefined;
            objectPropertyLeaseNo?: string | undefined;
            objectPropertySectionNo?: string | undefined;
            objectPropertyOrganizationNo?: string | undefined;
            objectPropertyShareNo?: string | undefined;
            propertyLevelCode?: string | undefined;
        }[];
        account: {
            interestGroupCode: string;
            sourceSystemCode: string;
            accountTypeCode: AccountType;
            accountSubtypeCode: AccountSubType;
            sourceApplicationID: string;
            originationDate: string;
            startDate: string;
            dueDay: number;
            nominalInterestRate: number;
            netLoanAmount: number;
            objectPrice: number;
            contractTypeCode?: string | undefined;
            limitAmount?: number | undefined;
            limitExpiryDate?: string | undefined;
            baseInterestRate?: number | undefined;
            equityAmount?: number | undefined;
            vatRate?: number | undefined;
            vatAmount?: number | undefined;
            contractDocTitle?: string | undefined;
            contractDocURL?: string | undefined;
            requireDirectDebit?: boolean | undefined;
            directDebitAccountNo?: string | undefined;
            directDebitAmountLimit?: number | undefined;
            initiateDirectDebit?: boolean | undefined;
            iban?: string | undefined;
            factoringInvoiceLimit?: number | undefined;
            disbursementBankAccountNo?: string | undefined;
            principalFreeTerms?: number | undefined;
            transparencyCode?: "ANSATTE" | "VIP" | undefined;
            tag?: {
                tagCode: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
        };
        product: {
            sourceProductID: string;
        };
        paymentSeries: {
            legNo: number;
            termLength: number;
            termCount: number;
            rateType: RateType;
            amortization: Amortization;
            interestRate: number;
            startBalance: number;
            endBalance: number;
            termFee: number;
            minAmountTermCount?: number | undefined;
            minAmountTermCountMax?: number | undefined;
            termDue?: number | undefined;
            netTermAmount?: number | undefined;
            grossTermAmount?: number | undefined;
        }[];
        contact: {
            sourceContactID: string;
            contactRoleCode: "SIGNER" | "COSIGNER" | "GUARANTOR" | "VENDOR" | "BROKER" | "SALESPERSON" | "INTERNALUNDERWRITER" | "INTERNALSALESPERSON" | "REPURCHASER" | "SUPPLIER" | "INSURANCE" | "CONTACTPERSON" | "UBO" | "POA" | "OTHER";
            socialSecurityNo: string;
            firstName: string;
            middleName: string;
            surname: string;
            eMail: string;
            mobilePhoneNo: string;
            nationalityCode: string;
            address: string;
            postCode: string;
            city: string;
            countryCode: string;
            languageCode: string;
            pep: number;
            riskLevelAML: number;
            citizenshipCode: string[];
            otherRole?: string | undefined;
            accountShare?: number | undefined;
            organizationNo?: string | undefined;
            dateOfBirthOrReg?: string | undefined;
            sectorCode?: string | undefined;
            economicActivityCode?: string | undefined;
            legalEntityTypeCode?: string | undefined;
            companyName?: string | undefined;
            salutationCode?: string | undefined;
            jobTitle?: string | undefined;
            invoiceEMail?: string | undefined;
            reminderEMail?: string | undefined;
            phoneNo?: string | undefined;
            address2?: string | undefined;
            streetType?: string | undefined;
            region?: string | undefined;
            optOutOfEcommunication?: boolean | undefined;
            emarketing?: boolean | undefined;
            guarantorType?: string | undefined;
            guarantorAmount?: number | undefined;
            guarantorExpiryDate?: string | undefined;
            kycAnswer?: {
                questionID: string;
                answer: string;
                timestamp?: string | undefined;
            }[] | undefined;
            dateOfLastKYC?: string | undefined;
            contactPreferences?: {
                eCommunication?: boolean | undefined;
                eMarketing?: boolean | undefined;
                eMarketingSms?: boolean | undefined;
                eMarketingEmail?: boolean | undefined;
                text?: string[] | undefined;
            } | undefined;
        }[];
        disbursement: {
            recipientType: "VENDOR" | "CUSTOMER" | "INTERNALACCOUNT";
            paymentDate: string;
            amount: number;
            sourceDisbursementID?: string | undefined;
            coreAccountNo?: string | undefined;
            bankAccountNo?: string | undefined;
            currency?: string | undefined;
            paymentReference?: string | undefined;
            paymentText?: string | undefined;
        }[];
        fee: {
            feeCode: string;
            feeAmount: number;
            includeInInterestCalc: boolean;
            feeIsFinanced: boolean;
            sourceFeeID?: string | undefined;
            feeTypeCode?: string | undefined;
            feeAmountType?: string | undefined;
            feeValueType?: string | undefined;
            feeValue?: number | undefined;
        }[];
        brand: {
            brandCode: string;
            brandOrgNo?: string | undefined;
            brandCompany?: string | undefined;
        }[];
        security: {
            tag?: {
                tagCode: string;
                sourceSecurityID: string;
                description?: string | undefined;
                expireDate?: string | undefined;
            }[] | undefined;
            sourceObjectID?: string | undefined;
            coreSecurityID?: string | undefined;
            sourceSecurityID?: string | undefined;
            securityTypeCode?: string | undefined;
            securityTypeText?: string | undefined;
            securityFaceValue?: number | undefined;
            securityExpirationDate?: string | undefined;
            securityOrderOfPriority?: number | undefined;
            securityPriorityAmount?: number | undefined;
            securityDescription?: string | undefined;
            securityRegistrationDate?: string | undefined;
            registrationDocumentNo?: string | undefined;
            registrationDocumentYear?: string | undefined;
            registrationOfficeNo?: string | undefined;
            registrationRightNo?: string | undefined;
            securityExternal?: boolean | undefined;
            securityExternalFaceValue?: number | undefined;
            securityExternalPart?: string | undefined;
            securityContacts?: {
                sourceContactID: string;
                ownerShare: number;
            }[] | undefined;
        }[];
        securityObject: {
            sourceObjectID: string;
            sourceSecurityID: string;
            priority?: number | undefined;
        }[];
        accountDocument: {
            documentType: string;
            documentTitle: string;
            documentURL: string;
            sourceDocumentGUID?: string | undefined;
            documentContent?: string | undefined;
            documentContentFileType?: string | undefined;
            showInMyPage?: boolean | undefined;
            sentForReservation?: boolean | undefined;
        }[];
        accountDimension?: {
            dimensionCode: string;
            dimensionValue: string;
            dimensionDescription: string;
        }[] | undefined;
        text?: string[] | undefined;
        additionalProduct?: {
            productCode: string;
            startDate: string;
            endDate: string;
            priceCalcType: string;
            priceCalcValue: number;
            consentDate: string;
            freeTerms: number;
            minimumPrice: number;
        }[] | undefined;
    };
}>;
export type CreateAccountRequest = z.infer<typeof createAccountRequestSchema>;
